@@ -13,7 +13,7 @@ Usage::
     ```
 """
 import sys
-from typing import Any, Dict, List, Type, overload
+from typing import Any, Dict, Mapping, Sequence, Type, overload
 
 from botocore.client import BaseClient, ClientMeta
 
@@ -85,7 +85,7 @@ __all__ = ("MachineLearningClient",)
 class BotocoreClientError(BaseException):
     MSG_TEMPLATE: str
 
-    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+    def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
         self.response: Dict[str, Any]
         self.operation_name: str
 
@@ -104,7 +104,7 @@ class Exceptions:
 
 class MachineLearningClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html)
     """
 
@@ -117,12 +117,16 @@ class MachineLearningClient(BaseClient):
         """
 
     def add_tags(
-        self, *, Tags: List["TagTypeDef"], ResourceId: str, ResourceType: TaggableResourceTypeType
+        self,
+        *,
+        Tags: Sequence["TagTypeDef"],
+        ResourceId: str,
+        ResourceType: TaggableResourceTypeType
     ) -> AddTagsOutputTypeDef:
         """
         Adds one or more tags to an object, up to a limit of 10.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#add_tags)
         """
 
@@ -130,7 +134,7 @@ class MachineLearningClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#can_paginate)
         """
 
@@ -141,12 +145,12 @@ class MachineLearningClient(BaseClient):
         MLModelId: str,
         BatchPredictionDataSourceId: str,
         OutputUri: str,
-        BatchPredictionName: str = None
+        BatchPredictionName: str = ...
     ) -> CreateBatchPredictionOutputTypeDef:
         """
         Generates predictions for a group of observations.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_batch_prediction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_batch_prediction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_batch_prediction)
         """
 
@@ -156,14 +160,14 @@ class MachineLearningClient(BaseClient):
         DataSourceId: str,
         RDSData: "RDSDataSpecTypeDef",
         RoleARN: str,
-        DataSourceName: str = None,
-        ComputeStatistics: bool = None
+        DataSourceName: str = ...,
+        ComputeStatistics: bool = ...
     ) -> CreateDataSourceFromRDSOutputTypeDef:
         """
         Creates a `DataSource` object from an `Amazon Relational Database Service
         <http://aws.amazon.com/rds/>`__ (Amazon RDS).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_rds)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_rds)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_data_source_from_rds)
         """
 
@@ -173,13 +177,13 @@ class MachineLearningClient(BaseClient):
         DataSourceId: str,
         DataSpec: "RedshiftDataSpecTypeDef",
         RoleARN: str,
-        DataSourceName: str = None,
-        ComputeStatistics: bool = None
+        DataSourceName: str = ...,
+        ComputeStatistics: bool = ...
     ) -> CreateDataSourceFromRedshiftOutputTypeDef:
         """
         Creates a `DataSource` from a database hosted on an Amazon Redshift cluster.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_redshift)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_redshift)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_data_source_from_redshift)
         """
 
@@ -188,13 +192,13 @@ class MachineLearningClient(BaseClient):
         *,
         DataSourceId: str,
         DataSpec: "S3DataSpecTypeDef",
-        DataSourceName: str = None,
-        ComputeStatistics: bool = None
+        DataSourceName: str = ...,
+        ComputeStatistics: bool = ...
     ) -> CreateDataSourceFromS3OutputTypeDef:
         """
         Creates a `DataSource` object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_s3)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_data_source_from_s3)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_data_source_from_s3)
         """
 
@@ -204,12 +208,12 @@ class MachineLearningClient(BaseClient):
         EvaluationId: str,
         MLModelId: str,
         EvaluationDataSourceId: str,
-        EvaluationName: str = None
+        EvaluationName: str = ...
     ) -> CreateEvaluationOutputTypeDef:
         """
         Creates a new `Evaluation` of an `MLModel`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_evaluation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_evaluation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_evaluation)
         """
 
@@ -219,16 +223,16 @@ class MachineLearningClient(BaseClient):
         MLModelId: str,
         MLModelType: MLModelTypeType,
         TrainingDataSourceId: str,
-        MLModelName: str = None,
-        Parameters: Dict[str, str] = None,
-        Recipe: str = None,
-        RecipeUri: str = None
+        MLModelName: str = ...,
+        Parameters: Mapping[str, str] = ...,
+        Recipe: str = ...,
+        RecipeUri: str = ...
     ) -> CreateMLModelOutputTypeDef:
         """
         Creates a new `MLModel` using the `DataSource` and the recipe as information
         sources.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_ml_model)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_ml_model)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_ml_model)
         """
 
@@ -236,7 +240,7 @@ class MachineLearningClient(BaseClient):
         """
         Creates a real-time endpoint for the `MLModel`.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.create_realtime_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.create_realtime_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#create_realtime_endpoint)
         """
 
@@ -246,7 +250,7 @@ class MachineLearningClient(BaseClient):
         """
         Assigns the DELETED status to a `BatchPrediction` , rendering it unusable.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_batch_prediction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_batch_prediction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_batch_prediction)
         """
 
@@ -254,7 +258,7 @@ class MachineLearningClient(BaseClient):
         """
         Assigns the DELETED status to a `DataSource` , rendering it unusable.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_data_source)
         """
 
@@ -262,7 +266,7 @@ class MachineLearningClient(BaseClient):
         """
         Assigns the `DELETED` status to an `Evaluation` , rendering it unusable.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_evaluation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_evaluation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_evaluation)
         """
 
@@ -270,7 +274,7 @@ class MachineLearningClient(BaseClient):
         """
         Assigns the `DELETED` status to an `MLModel` , rendering it unusable.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_ml_model)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_ml_model)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_ml_model)
         """
 
@@ -278,107 +282,107 @@ class MachineLearningClient(BaseClient):
         """
         Deletes a real time endpoint of an `MLModel` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_realtime_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_realtime_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_realtime_endpoint)
         """
 
     def delete_tags(
-        self, *, TagKeys: List[str], ResourceId: str, ResourceType: TaggableResourceTypeType
+        self, *, TagKeys: Sequence[str], ResourceId: str, ResourceType: TaggableResourceTypeType
     ) -> DeleteTagsOutputTypeDef:
         """
         Deletes the specified tags associated with an ML object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.delete_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.delete_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#delete_tags)
         """
 
     def describe_batch_predictions(
         self,
         *,
-        FilterVariable: BatchPredictionFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None
+        FilterVariable: BatchPredictionFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...
     ) -> DescribeBatchPredictionsOutputTypeDef:
         """
         Returns a list of `BatchPrediction` operations that match the search criteria in
         the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.describe_batch_predictions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.describe_batch_predictions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#describe_batch_predictions)
         """
 
     def describe_data_sources(
         self,
         *,
-        FilterVariable: DataSourceFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None
+        FilterVariable: DataSourceFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...
     ) -> DescribeDataSourcesOutputTypeDef:
         """
         Returns a list of `DataSource` that match the search criteria in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.describe_data_sources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.describe_data_sources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#describe_data_sources)
         """
 
     def describe_evaluations(
         self,
         *,
-        FilterVariable: EvaluationFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None
+        FilterVariable: EvaluationFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...
     ) -> DescribeEvaluationsOutputTypeDef:
         """
         Returns a list of `DescribeEvaluations` that match the search criteria in the
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.describe_evaluations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.describe_evaluations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#describe_evaluations)
         """
 
     def describe_ml_models(
         self,
         *,
-        FilterVariable: MLModelFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None
+        FilterVariable: MLModelFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...
     ) -> DescribeMLModelsOutputTypeDef:
         """
         Returns a list of `MLModel` that match the search criteria in the request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.describe_ml_models)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.describe_ml_models)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#describe_ml_models)
         """
 
@@ -388,21 +392,21 @@ class MachineLearningClient(BaseClient):
         """
         Describes one or more of the tags for your Amazon ML object.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.describe_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.describe_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#describe_tags)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Dict[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#generate_presigned_url)
         """
 
@@ -411,18 +415,18 @@ class MachineLearningClient(BaseClient):
         Returns a `BatchPrediction` that includes detailed metadata, status, and data
         file information for a `Batch Prediction` request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.get_batch_prediction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.get_batch_prediction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#get_batch_prediction)
         """
 
     def get_data_source(
-        self, *, DataSourceId: str, Verbose: bool = None
+        self, *, DataSourceId: str, Verbose: bool = ...
     ) -> GetDataSourceOutputTypeDef:
         """
         Returns a `DataSource` that includes metadata and data file information, as well
         as the current status of the `DataSource` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.get_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.get_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#get_data_source)
         """
 
@@ -431,26 +435,26 @@ class MachineLearningClient(BaseClient):
         Returns an `Evaluation` that includes metadata as well as the current status of
         the `Evaluation` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.get_evaluation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.get_evaluation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#get_evaluation)
         """
 
-    def get_ml_model(self, *, MLModelId: str, Verbose: bool = None) -> GetMLModelOutputTypeDef:
+    def get_ml_model(self, *, MLModelId: str, Verbose: bool = ...) -> GetMLModelOutputTypeDef:
         """
         Returns an `MLModel` that includes detailed metadata, data source information,
         and the current status of the `MLModel` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.get_ml_model)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.get_ml_model)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#get_ml_model)
         """
 
     def predict(
-        self, *, MLModelId: str, Record: Dict[str, str], PredictEndpoint: str
+        self, *, MLModelId: str, Record: Mapping[str, str], PredictEndpoint: str
     ) -> PredictOutputTypeDef:
         """
         Generates a prediction for the observation using the specified `ML Model` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.predict)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.predict)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#predict)
         """
 
@@ -460,7 +464,7 @@ class MachineLearningClient(BaseClient):
         """
         Updates the `BatchPredictionName` of a `BatchPrediction` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.update_batch_prediction)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.update_batch_prediction)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#update_batch_prediction)
         """
 
@@ -470,7 +474,7 @@ class MachineLearningClient(BaseClient):
         """
         Updates the `DataSourceName` of a `DataSource` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.update_data_source)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.update_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#update_data_source)
         """
 
@@ -480,17 +484,17 @@ class MachineLearningClient(BaseClient):
         """
         Updates the `EvaluationName` of an `Evaluation` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.update_evaluation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.update_evaluation)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#update_evaluation)
         """
 
     def update_ml_model(
-        self, *, MLModelId: str, MLModelName: str = None, ScoreThreshold: float = None
+        self, *, MLModelId: str, MLModelName: str = ..., ScoreThreshold: float = ...
     ) -> UpdateMLModelOutputTypeDef:
         """
         Updates the `MLModelName` and the `ScoreThreshold` of an `MLModel` .
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Client.update_ml_model)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Client.update_ml_model)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/client.html#update_ml_model)
         """
 
@@ -499,7 +503,7 @@ class MachineLearningClient(BaseClient):
         self, operation_name: Literal["describe_batch_predictions"]
     ) -> DescribeBatchPredictionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
         """
 
@@ -508,7 +512,7 @@ class MachineLearningClient(BaseClient):
         self, operation_name: Literal["describe_data_sources"]
     ) -> DescribeDataSourcesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
         """
 
@@ -517,7 +521,7 @@ class MachineLearningClient(BaseClient):
         self, operation_name: Literal["describe_evaluations"]
     ) -> DescribeEvaluationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
         """
 
@@ -526,7 +530,7 @@ class MachineLearningClient(BaseClient):
         self, operation_name: Literal["describe_ml_models"]
     ) -> DescribeMLModelsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
         """
 
@@ -535,7 +539,7 @@ class MachineLearningClient(BaseClient):
         self, waiter_name: Literal["batch_prediction_available"]
     ) -> BatchPredictionAvailableWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#batchpredictionavailablewaiter)
         """
 
@@ -544,20 +548,20 @@ class MachineLearningClient(BaseClient):
         self, waiter_name: Literal["data_source_available"]
     ) -> DataSourceAvailableWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#datasourceavailablewaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["evaluation_available"]) -> EvaluationAvailableWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#evaluationavailablewaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["ml_model_available"]) -> MLModelAvailableWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#mlmodelavailablewaiter)
         """
