@@ -64,103 +64,103 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
     """
 
     def paginate(
         self,
         *,
-        FilterVariable: BatchPredictionFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        FilterVariable: BatchPredictionFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describebatchpredictionspaginator)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
     """
 
     def paginate(
         self,
         *,
-        FilterVariable: DataSourceFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        FilterVariable: DataSourceFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describedatasourcespaginator)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
     """
 
     def paginate(
         self,
         *,
-        FilterVariable: EvaluationFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        FilterVariable: EvaluationFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describeevaluationspaginator)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
     """
 
     def paginate(
         self,
         *,
-        FilterVariable: MLModelFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        FilterVariable: MLModelFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeMLModelsOutputTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/paginators.html#describemlmodelspaginator)
         """
