@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Mapping, Sequence
 
 from .literals import (
     BatchPredictionFilterVariableType,
@@ -120,7 +120,7 @@ __all__ = (
 AddTagsInputRequestTypeDef = TypedDict(
     "AddTagsInputRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
     },
@@ -332,7 +332,7 @@ _OptionalCreateMLModelInputRequestTypeDef = TypedDict(
     "_OptionalCreateMLModelInputRequestTypeDef",
     {
         "MLModelName": str,
-        "Parameters": Dict[str, str],
+        "Parameters": Mapping[str, str],
         "Recipe": str,
         "RecipeUri": str,
     },
@@ -474,7 +474,7 @@ DeleteRealtimeEndpointOutputTypeDef = TypedDict(
 DeleteTagsInputRequestTypeDef = TypedDict(
     "DeleteTagsInputRequestTypeDef",
     {
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
         "ResourceId": str,
         "ResourceType": TaggableResourceTypeType,
     },
@@ -841,7 +841,7 @@ PredictInputRequestTypeDef = TypedDict(
     "PredictInputRequestTypeDef",
     {
         "MLModelId": str,
-        "Record": Dict[str, str],
+        "Record": Mapping[str, str],
         "PredictEndpoint": str,
     },
 )
@@ -875,7 +875,7 @@ _RequiredRDSDataSpecTypeDef = TypedDict(
         "ResourceRole": str,
         "ServiceRole": str,
         "SubnetId": str,
-        "SecurityGroupIds": List[str],
+        "SecurityGroupIds": Sequence[str],
     },
 )
 _OptionalRDSDataSpecTypeDef = TypedDict(
