@@ -45,111 +45,111 @@ __all__ = (
 
 class BatchPredictionAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#batchpredictionavailablewaiter)
     """
 
     def wait(
         self,
         *,
-        FilterVariable: BatchPredictionFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        FilterVariable: BatchPredictionFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#batchpredictionavailablewaiter)
         """
 
 
 class DataSourceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#datasourceavailablewaiter)
     """
 
     def wait(
         self,
         *,
-        FilterVariable: DataSourceFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        FilterVariable: DataSourceFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#datasourceavailablewaiter)
         """
 
 
 class EvaluationAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#evaluationavailablewaiter)
     """
 
     def wait(
         self,
         *,
-        FilterVariable: EvaluationFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        FilterVariable: EvaluationFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#evaluationavailablewaiter)
         """
 
 
 class MLModelAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#mlmodelavailablewaiter)
     """
 
     def wait(
         self,
         *,
-        FilterVariable: MLModelFilterVariableType = None,
-        EQ: str = None,
-        GT: str = None,
-        LT: str = None,
-        GE: str = None,
-        LE: str = None,
-        NE: str = None,
-        Prefix: str = None,
-        SortOrder: SortOrderType = None,
-        NextToken: str = None,
-        Limit: int = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        FilterVariable: MLModelFilterVariableType = ...,
+        EQ: str = ...,
+        GT: str = ...,
+        LT: str = ...,
+        GE: str = ...,
+        LE: str = ...,
+        NE: str = ...,
+        Prefix: str = ...,
+        SortOrder: SortOrderType = ...,
+        NextToken: str = ...,
+        Limit: int = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.39/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_machinelearning/waiters.html#mlmodelavailablewaiter)
         """
